@@ -1,9 +1,9 @@
-use cargo_leptos::{config::Cli, ext::anyhow::Result, run};
+use cargo_leptos::{config::Cli, run};
 use clap::Parser;
 use std::env;
 
 #[tokio::main]
-async fn main() -> Result<()> {
+async fn main() -> color_eyre::Result<()> {
     let mut args: Vec<String> = env::args().collect();
     // when running as cargo leptos, the second argument is "leptos" which
     // clap doesn't expect
@@ -12,5 +12,10 @@ async fn main() -> Result<()> {
     }
 
     let args = Cli::parse_from(&args);
+
+    let verbose = args.opts().map(|o| o.verbose).unwrap_or(0);
+    cargo_leptos::logger::setup(verbose, &args.log);
+    color_eyre::install()?;
+
     run(args).await
 }
